import util

from django.template import RequestContext
from django.shortcuts import render_to_response
from django.http import Http404

from lava_server.views import index as lava_index
from lava_server.bread_crumbs import (
     BreadCrumb,
     BreadCrumbTrail,
)

# Import test handlers
import glmark2_es2_views, glmark2_es2_validate_views

@BreadCrumb("Graphics", parent=lava_index)
def index(request):
    status_dict = {}

    # Populate the status dictionary
    for t in util.get_test_list():
        module = util.get_module_for_test(t)
        for b in util.BOARD_LIST:
            status_dict[b + "-" + t] = module.get_status(b, t)

    return render_to_response(
            "linaro_graphics_app/index.html",
            {
                "bread_crumb_trail": BreadCrumbTrail.leading_to(index),
                "board_list": util.BOARD_LIST,
                "test_list": util.get_test_list(),
                "status_dict": status_dict
            },
            RequestContext(request))

@BreadCrumb("{board_name}", parent=index, needs=["board_name"])
def board(request, board_name):
    if not board_name in util.BOARD_LIST:
        raise Http404

    return render_to_response(
            "linaro_graphics_app/board.html",
            {
                "bread_crumb_trail": BreadCrumbTrail.leading_to(
                    board,
                    board_name=board_name),
                "board_name": board_name,
                "test_list": util.get_test_list()
            },
            RequestContext(request))

@BreadCrumb("{test_id}", parent=board, needs=["board_name", "test_id"])
def test(request, board_name, test_id):
    # Ensure the board is supported
    if not board_name in util.BOARD_LIST:
        raise Http404

    # Get the module handling the test
    module = util.get_module_for_test(test_id)
    if module is None:
        raise Http404

    # Get response arguments
    args = module.get_response_args_for_test(request, board_name, test_id)

    # Make some useful variables available to the template
    args[1].update({
                       "bread_crumb_trail": BreadCrumbTrail.leading_to(
                            test,
                            test_id=test_id,
                            board_name=board_name),
                       "board_name": board_name,
                       "test_id": test_id
                   })

    return render_to_response(*args)

@BreadCrumb("{test_case_id}", parent=test, needs=["board_name", "test_id", "test_case_id"])
def test_case(request, board_name, test_id, test_case_id):
    # Ensure the board is supported
    if not board_name in util.BOARD_LIST:
        raise Http404

    # Get the module handling the test
    module = util.get_module_for_test(test_id)
    if module is None:
        raise Http404

    # Get response arguments
    args = module.get_response_args_for_test_case(request, board_name, test_id, test_case_id)

    # Make some useful variables available to the template
    args[1].update({
                       "bread_crumb_trail": BreadCrumbTrail.leading_to(
                            test,
                            test_id=test_id,
                            board_name=board_name),
                       "board_name": board_name,
                       "test_id": test_id,
                       "test_case_id": test_case_id
                   })

    return render_to_response(*args)
