import util
import time

from django.template import RequestContext

from dashboard_app.models import TestResult

_result_to_string = {
        TestResult.RESULT_PASS: "pass",
        TestResult.RESULT_FAIL: "fail",
        TestResult.RESULT_SKIP: "skip",
        TestResult.RESULT_UNKNOWN: "unknown"
        }

def get_response_args_for_test(request, board_name, test_id):
    """ Get arguments for test case view response"""

    test_run_list_query = util.get_test_run_query(util.DAILY_STREAM,
                                                  test_id, board_name, 30)

    test_result_list = []
    last_result_list = []

    if test_run_list_query.count() > 0:
        for test_run in test_run_list_query:
            result = {"pass": 0, "fail": 0, "unknown": 0}
            for test_result in test_run.test_results.all():
                result[_result_to_string[test_result.result]] += 1
            t = time.mktime(test_run.analyzer_assigned_date.timetuple())
            test_result_list.append({"time":t, "value":result})

        for test_result in test_run_list_query.reverse()[0].test_results.all():
            last_result_list.append(
                    {
                        "id":test_result.test_case.test_case_id,
                        "result":_result_to_string[test_result.result]
                    }
            )

    return ("linaro_graphics_app/glmark2_es2_validate.html",
            {
                "test_result_list": test_result_list,
                "last_result_list": last_result_list,
            },
            RequestContext(request))


def get_response_args_for_test_case(request, board_name, test_id, test_case_id):
    """ Get arguments for test case view response"""

    test_run_list_query = util.get_test_run_query(util.DAILY_STREAM,
                                                  test_id, board_name, 30)

    test_result_list = []

    for test_run in test_run_list_query:
        t = time.mktime(test_run.analyzer_assigned_date.timetuple())
        try:
            v = test_run.test_results.get(test_case__test_case_id=test_case_id).result
        except:
            v = TestResult.RESULT_UNKNOWN

        result = {"pass": 0, "fail": 0, "unknown": 0}
        result[_result_to_string[v]] += 1
        test_result_list.append({"time":t, "value":result})


    return ("linaro_graphics_app/test_case_result.html",
            {
                "test_result_list": test_result_list
            },
            RequestContext(request))


def get_status(board_name, test_id):
    """Gets the status of this test for a specific board"""
    return "good"
