import util
import time

from django.template import RequestContext

def get_response_args_for_test(request, board_name, test_id):
    """ Get arguments for test view response"""

    test_run_list_query = util.get_test_run_query(util.DAILY_STREAM,
                                                  test_id, board_name, 30)

    avg_result_list = []
    last_result_list = []

    if test_run_list_query.count() > 0:
        # Create a list of average results
        for test_run in test_run_list_query:
            result = 0.0
            for test_result in test_run.test_results.all():
                result += float(test_result.measurement)
            length = test_run.test_results.all().count()
            if length > 0:
                result /= length
            t = time.mktime(test_run.analyzer_assigned_date.timetuple())
            avg_result_list.append({"time":t, "value":result})

        # Create a list of detailed test case results from the last run
        for test_result in test_run_list_query.reverse()[0].test_results.all():
            last_result_list.append(
                    {
                        "id":test_result.test_case.test_case_id,
                        "measurement":test_result.measurement,
                    }
            )

    return ("linaro_graphics_app/glmark2_es2.html",
            {
                "avg_result_list": avg_result_list,
                "last_result_list": last_result_list,
            },
            RequestContext(request))

def get_response_args_for_test_case(request, board_name, test_id, test_case_id):
    """ Get arguments for test case view response"""

    test_run_list_query = util.get_test_run_query(util.DAILY_STREAM,
                                                  test_id, board_name, 30)

    test_result_list = []

    for test_run in test_run_list_query:
        t = time.mktime(test_run.analyzer_assigned_date.timetuple())
        try:
            v = test_run.test_results.get(test_case__test_case_id=test_case_id).measurement
        except:
            v = 0.0
        test_result_list.append({"time":t, "value":v})


    return ("linaro_graphics_app/test_case_measurement.html",
            {
                "test_result_list": test_result_list
            },
            RequestContext(request))

def get_status(board_name, test_id):
    """Gets the status of this test for a specific board"""
    return "good"
